@@ -357,8 +357,10 @@ def connect(service_name: str = None, router_name: str = None, timeout: int = 0,
     :type traceroute: bool, optional
     :return: :class:`Connection`
     """
-    api_cls = RouterAPI if router_name else ControllerAPI
     dest_name = router_name or service_name
+    if not dest_name:
+        raise ValueError("Must supply service_name or router_name for connect()")
+    api_cls = RouterAPI if router_name else ControllerAPI
     api = api_cls(host=Config.CONTROLLER_HOST, api_key=Config.API_KEY)
     status = api.get_status(dest_name)
     if not status.get("ready"):
