@@ -145,13 +145,6 @@ class Function:
         os.makedirs(persistent_dir, exist_ok=True)
         return os.path.join(persistent_dir, self.name)
 
-    @property
-    def default_volatile_dir(self):
-        data_dir = '/tmp/volatile_data'
-        volatile = os.path.join(data_dir, os.environ.get('HOSTNAME'))
-        os.makedirs(volatile, exist_ok=True)
-        return os.path.join(volatile, self.name)
-
     @property
     def full(self) -> bool:
         if MEMORY_LIMIT_MB == 0:  # no limit
