@@ -33,8 +33,8 @@ def start(servlet_spec: ServletSpec, wal=False, persistent_dir=None, num_replica
     else:
         servlet = ZMQServlet(servlet_spec)
 
-    loop.create_task(servlet.poll())
-    loop.create_task(servlet.refresh_dns())
+    servlet.start_polling()
+    servlet.refresh_dns()
     loop.run_forever()
     if servlet.exception is not None and type(servlet.exception) == RestartException:
         raise RestartException
