@@ -7,7 +7,7 @@ from pinecone.runnable import Runnable
 from pinecone.network.zmq import Socket, ServletSpec, entrypoints
 from pinecone.network.selector.shards import ShardSelector
 from pinecone.utils.constants import ZMQ_PORT_IN, ZMQ_LOG_PORT, ZMQ_CONTROL_PORT
-from pinecone.utils import load_hub_service, module_name, replica_name, parse_hostname, get_hostname
+from pinecone.utils import load_hub_service, module_name, parse_hostname, get_hostname
 from pinecone.protos import core_pb2
 
 import concurrent.futures
